@@ -308,6 +308,7 @@ STYLES = {
     "pinky_down": pinky_down,
     "pinky_updown": pinky_updown,
     "pinky_downup": pinky_downup,
+    "random": random_shuffle,
     "random_shuffle": random_shuffle,
     "random_octaves": random_octaves,
     "random_silence": random_silence,
@@ -322,6 +323,8 @@ def apply_style(notes: List[int], style: str = "down", **kwargs) -> List[int]:
     """
     Apply a style to a list of notes
     """
+    if style not in STYLES:
+        raise ValueError(f'Style "{style}" is not valid. Choose from:\n\n{", ".join(STYLES.keys())}')
     return STYLES.get(style)(notes, **kwargs)
 
 
@@ -354,11 +357,11 @@ def _gen_silence(duration):
 def midi_arp(
     notes: List[int] = [],  # arbitrary list of notes to arpeggiate
     root: str = "A3",  # root note of chord
-    octaves: List[int] = [0],  # a list of octaves to add to the notes (eg: [-1, 2])
     chord: str = "minor",  # chord name,
     inversions: List[int] = [],  # inversions list
     stack: int = 0,  # stack a chord up or down
     styles: List[str] = ["down"],
+    octaves: List[int] = [0],  # a list of octaves to add to the notes (eg: [-1, 2])
     velocities: List[int] = [100],
     # a list of velocities to apply across notes,
     # velocities are retrieved using a modulo so
