@@ -269,29 +269,29 @@ MIDI_TO_FREQ = {
 # TODO: add chord / inversion functionality
 CHORDS = {
     "MAJ": [0, 4, 7],
-    "MAJ_NO_5": [0, 4],
+    "MAJ_NO5": [0, 4],
     "POWER": [0, 7],
     "SUS": [0, 5, 7],
     "SUS2": [0, 2, 7],
     "7SUS": [0, 5, 7],
     "7SUS2": [0, 2, 7],
     "MAJ6": [0, 4, 7, 9],
-    "MAJ6_NO_5": [0, 4, 9],
+    "MAJ6_NO5": [0, 4, 9],
     "MAJ6_9": [0, 4, 9, 14],
     "MAJ9": [0, 4, 7, 14],
     "MIN": [0, 3, 7],
-    "MIN_NO_5": [0, 3],
+    "MIN_NO5": [0, 3],
     "MIN6": [0, 3, 7, 9],
-    "MIN6_NO_5": [0, 3, 9],
+    "MIN6_NO5": [0, 3, 9],
     "MIN6_9": [0, 3, 9, 14],
     "DIM": [0, 3, 6],
     "AUG": [0, 4, 8],
     "MAJ7": [0, 4, 7, 11],
-    "MAJ7_NO_5": [0, 4, 11],
+    "MAJ7_NO5": [0, 4, 11],
     "MIN7": [0, 3, 7, 10],
-    "MIN7_NO_5": [0, 3, 10],
+    "MIN7_NO5": [0, 3, 10],
     "MAJ9": [0, 4, 7, 14],
-    "MAJ9_NO_5": [0, 4, 14],
+    "MAJ9_NO5": [0, 4, 14],
 }
 
 SCALES = {
